@@ -147,7 +147,7 @@ class Instance(Type):
 
 class Item(Instance):
     
-    def __init__(self, owner_id, org_id, instance, id, name, attributes=dict(), items=[], acls=[]):
+    def __init__(self, owner_id, org_id, instance, id, name, attributes=dict(), items=[], acls=[], linked_item_id=None):
         self.owner_id = owner_id
         self.org_id = org_id
         self.id = id
@@ -156,9 +156,14 @@ class Item(Instance):
         self._attributes = attributes
         self.items = items
         self.acls = acls
+        self.linked_item_id = linked_item_id
 
     def _get_attributes(self):
-        return  self.instance.attributes | self._attributes if self._attributes else self.instance.attributes
+        try:
+            return  self.instance.attributes | self._attributes if self._attributes else self.instance.attributes
+        except Exception as e:
+            print(e)
+            return self._attributes
 
     def _del_attributes(self):
         self._attributes = dict()
@@ -185,13 +190,16 @@ class Item(Instance):
         pass
 
     def to_dict(self):
-        return {
+        result = {
             'id': self.id,
             'name': self.name,
             'type': self.instance.type.to_dict(),
             'attributes': self.attributes,
             'items': [i.to_dict() for i in self.items]
         }
+        if self.linked_item_id:
+            result['linked_item_id'] = self.linked_item_id
+        return result
 
 
 class Data:
@@ -273,14 +281,21 @@ class Org:
 
 class Account:
     
-    def __init__(self, id, name, org):
+    def __init__(self, id, name, org, org_role_type):
         self.id = id
         self.name = name
         self.org = org
+        self.org_role_type = org_role_type
 
     def get_user_id(self):
         return self.id
 
+    def is_superuser(self):
+        return self.org_role_type.name == 'superuser'
+
+    def is_admin(self):
+        return self.org_role_type.name == 'admin'
+
 class App:
     
     def __init__(self, id, name):
