@@ -275,12 +275,7 @@ def router(endpoint_name, path):
 
     account = None
     
-    content_type = 'text/html'
-
-    if request.accept_mimetypes.accept_json:
-        content_type = 'application/json'
-    elif 'application/xml' in request.accept_mimetypes:
-        content_type = 'application/xml'
+    content_type = request.accept_mimetypes.best
     
     if not current_token:
         account = current_user(contextProvider)
@@ -347,7 +342,7 @@ def router(endpoint_name, path):
     method = request.method.lower()
 
     if endpoint:
-        args = request.args.to_dict()
+        args = request.args.to_dict(flat=False)
 
         if request.method.lower() == 'post' or request.method.lower() == 'put':
             args |= request.form.to_dict()
